ConsumerParams class
Parameters for creating a consumer
Constructors
-
ConsumerParams({required String id, required String producerId, required String kind, required Map<
String, dynamic> rtpParameters}) -
const
-
ConsumerParams.fromJson(Map<
String, dynamic> json) -
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- id → String
-
final
- kind → String
-
final
- producerId → String
-
final
-
props
→ List<
Object?> -
The list of properties that will be used to determine whether
two instances are equal.
no setter
-
rtpParameters
→ Map<
String, dynamic> -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- stringify → bool?
-
If set to
true, thetoStringmethod will be overridden to output this instance'sprops.no setterinherited
Methods
-
copyWith(
{String? id, String? producerId, String? kind, Map< String, dynamic> ? rtpParameters}) → ConsumerParams -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String - A string representation of this object.
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited