ParticipantInfo class
Basic information about a participant
Constructors
-
ParticipantInfo({required String participantId, required String participantName, List<
String> producerIds = const []}) -
const
-
ParticipantInfo.fromJson(Map<
String, dynamic> json) -
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- participantId → String
-
final
- participantName → String
-
final
-
producerIds
→ List<
String> -
final
-
props
→ List<
Object?> -
The list of properties that will be used to determine whether
two instances are equal.
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- stringify → bool?
-
If set to
true, thetoStringmethod will be overridden to output this instance'sprops.no setterinherited
Methods
-
copyWith(
{String? participantId, String? participantName, List< String> ? producerIds}) → ParticipantInfo -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String - A string representation of this object.
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited