TransportOptions class
Options for creating a WebRTC transport
Constructors
Properties
-
dtlsParameters
→ Map<
String, dynamic> -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
iceCandidates
→ List<
Map< String, dynamic> > -
final
-
iceParameters
→ Map<
String, dynamic> -
final
- id → String
-
final
-
props
→ List<
Object?> -
The list of properties that will be used to determine whether
two instances are equal.
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
sctpParameters
→ Map<
String, dynamic> ? -
final
- stringify → bool?
-
If set to
true, thetoStringmethod will be overridden to output this instance'sprops.no setterinherited
Methods
-
copyWith(
{String? id, Map< String, dynamic> ? iceParameters, List<Map< ? iceCandidates, Map<String, dynamic> >String, dynamic> ? dtlsParameters, Map<String, dynamic> ? sctpParameters}) → TransportOptions -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String - A string representation of this object.
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited