TransportPair class
Pair of send and receive transports
Constructors
- TransportPair({required TransportOptions sendTransport, required TransportOptions recvTransport})
-
const
-
TransportPair.fromJson(Map<
String, dynamic> json) -
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
-
props
→ List<
Object?> -
The list of properties that will be used to determine whether
two instances are equal.
no setter
- recvTransport → TransportOptions
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sendTransport → TransportOptions
-
final
- stringify → bool?
-
If set to
true, thetoStringmethod will be overridden to output this instance'sprops.no setterinherited
Methods
-
copyWith(
{TransportOptions? sendTransport, TransportOptions? recvTransport}) → TransportPair -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String - A string representation of this object.
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited