props property
The list of properties that will be used to determine whether two instances are equal.
Implementation
@override
List<Object?> get props => [
version, // Include version to ensure state changes are always detected
status,
conferenceId,
participantId,
participantName,
localStreams,
participants,
error,
];