AudioConfig class

Audio configuration

Constructors

AudioConfig({bool? echoCancellation, bool? noiseSuppression, bool? autoGainControl, String? deviceId})
const

Properties

autoGainControl bool?
Enable auto gain control
final
deviceId String?
Specific device ID to use
final
echoCancellation bool?
Enable echo cancellation
final
hashCode int
The hash code for this object.
no setterinherited
noiseSuppression bool?
Enable noise suppression
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toConstraints() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited