LocalMedia class
Result from getLocalMedia containing streams and tracks
Constructors
-
LocalMedia({required MediaStream stream, MediaStreamTrack? audioTrack, MediaStreamTrack? videoTrack, required Set<
MediaType> capturedTypes}) -
const
Properties
-
allAudioTracks
→ List<
MediaStreamTrack> -
Get all audio tracks (mic + system audio)
no setter
-
allTracks
→ List<
MediaStreamTrack> -
Get all tracks
no setter
-
allVideoTracks
→ List<
MediaStreamTrack> -
Get all video tracks (camera + screenshare)
no setter
- audioTrack → MediaStreamTrack?
-
Audio track (if requested and available)
final
-
capturedTypes
→ Set<
MediaType> -
The media types that were successfully captured
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
Screen share audio track (if available - system audio)
final
-
Stream for screen share (separate from camera stream)
final
-
Screen share video track (if requested and available)
final
- stream → MediaStream
-
The MediaStream containing all tracks
final
-
tracksWithTypes
→ List<
TrackWithType> -
Get tracks with their types for producing
no setter
- videoTrack → MediaStreamTrack?
-
Video track (if requested and available)
final
Methods
-
dispose(
) → Future< void> - Dispose all streams and tracks
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited