LocalStream class
Local stream handle returned from produce()
Constructors
-
LocalStream({required String id, required StreamType type, required MediaStream stream, required MediaStreamTrack track, required bool paused, required Producer producer, required Future<
void> onPause(String), required Future<void> onResume(String), required Future<void> onStop(String)})
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- id → String
-
Unique stream ID (producer ID)
final
- paused → bool
-
Whether the stream is paused
no setter
- producer → Producer
-
Get the underlying producer
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- stream → MediaStream
-
The MediaStream containing the track
final
- track → MediaStreamTrack
-
The original track
final
- type → StreamType
-
Stream type
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
pause(
) → Future< void> - Pause the stream
-
resume(
) → Future< void> - Resume the stream
-
stop(
) → Future< void> - Stop and close the stream
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited