MediaConfig class

Configuration for getLocalMedia

Constructors

MediaConfig({bool audio = false, bool video = false, bool screenshare = false, AudioConfig? audioConfig, VideoConfig? videoConfig, ScreenShareConfig? screenshareConfig})
const

Properties

audio bool
Whether to capture audio (microphone)
final
audioConfig AudioConfig?
Audio constraints (optional)
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
screenshare bool
Whether to capture screen share
final
screenshareConfig ScreenShareConfig?
Screen share constraints (optional)
final
video bool
Whether to capture video (camera)
final
videoConfig VideoConfig?
Video constraints (optional)
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

audioOnly({AudioConfig? config}) MediaConfig
Create config for audio only
audioVideo({AudioConfig? audioConfig, VideoConfig? videoConfig}) MediaConfig
Create config for audio and video
screenShareOnly({ScreenShareConfig? config}) MediaConfig
Create config for screen share only
screenShareWithAudio({ScreenShareConfig? screenshareConfig, AudioConfig? audioConfig}) MediaConfig
Create config for screen share with audio
videoOnly({VideoConfig? config}) MediaConfig
Create config for video only