MediaType enum

Media types for getLocalMedia

Inheritance
Available extensions

Values

audio → const MediaType

Microphone audio

video → const MediaType

Camera video

screenshare → const MediaType

Screen/window share (includes system audio on supported platforms)

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value String

Available on MediaType, provided by the MediaTypeExtension extension

no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<MediaType>
A constant List of the values in this enum, in order of their declaration.