ParticipantLeftData class

Constructors

ParticipantLeftData({required String participantId, List<String> closedProducerIds = const [], List<String> closedConsumerIds = const []})
const
ParticipantLeftData.fromJson(Map<String, dynamic> json)
factory

Properties

closedConsumerIds List<String>
final
closedProducerIds List<String>
final
hashCode int
The hash code for this object.
no setterinherited
participantId String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited