ProduceInput class abstract
Input for produce() - can be single track, array of tracks, or tracks with types Use the factory methods for convenience
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
toTrackList(
) → List< TrackWithType>
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
fromTrack(
MediaStreamTrack track, {StreamType? type}) → ProduceInput - Create from a single track
-
fromTracks(
List< MediaStreamTrack> tracks) → ProduceInput - Create from multiple tracks
-
fromTracksWithTypes(
List< TrackWithType> tracks) → ProduceInput - Create from tracks with explicit types