ProducerInfo class

Internal producer info

Constructors

ProducerInfo({required String id, required StreamType type, required MediaStreamTrack track, required Producer producer, required MediaStream stream, bool paused = false, Map<String, dynamic>? stoppedTrackSettings})

Properties

hashCode int
The hash code for this object.
no setterinherited
id String
final
paused bool
getter/setter pair
producer → Producer
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
stoppedTrackSettings Map<String, dynamic>?
Stores the original track settings for re-acquisition on resume Only used for video tracks that were stopped (not just paused)
getter/setter pair
stream MediaStream
getter/setter pair
track MediaStreamTrack
getter/setter pair
type StreamType
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited