QuickRTCConfig class
Configuration for QuickRTC client instance
Constructors
- QuickRTCConfig({required Socket socket, int maxParticipants = 0, bool debug = false})
-
const
Properties
- debug → bool
-
Enable debug logging
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- maxParticipants → int
-
Maximum participants allowed (0 = unlimited)
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- socket → Socket
-
Socket.IO client instance
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited