StreamRemovedEvent class

Stream removed event data

Constructors

StreamRemovedEvent({required String participantId, required String streamId, required StreamType type})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
participantId String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
streamId String
final
type StreamType
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited