StreamResumedEvent class
Stream resumed event (remote participant unmuted audio/video)
Constructors
- StreamResumedEvent({required String participantId, required StreamType type})
-
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- participantId → String
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- type → StreamType
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited