sourceStream property

MediaStream? sourceStream
final

The original MediaStream from getUserMedia. On macOS, the camera is only released when this specific stream is disposed. Pass this to ensure proper camera release on pause.

Implementation

final MediaStream? sourceStream;