TransportOptionsData class
Transport options from server
Constructors
Properties
-
dtlsParameters
→ Map<
String, dynamic> -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- iceCandidates → List
-
final
-
iceParameters
→ Map<
String, dynamic> -
final
- id → String
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
sctpParameters
→ Map<
String, dynamic> ? -
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited