VideoConfig class
Video configuration
Constructors
Properties
- deviceId → String?
-
Specific device ID to use
final
- facingMode → String?
-
Facing mode ('user' for front camera, 'environment' for back camera)
final
- frameRate → int?
-
Preferred frame rate
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- height → int?
-
Preferred height
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- width → int?
-
Preferred width
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toConstraints(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- backCamera → const VideoConfig
- Back camera preset (720p)
- frontCamera → const VideoConfig
- Front camera preset (720p)
- fullHd → const VideoConfig
- Full HD preset (1080p)
- hd → const VideoConfig
- HD preset (720p)
- uhd4k → const VideoConfig
- 4K preset