AudioStreamEntry class

Entry for audio stream in QuickRTCAudioGroup

Constructors

AudioStreamEntry({required String id, required MediaStream stream, bool muted = false})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
id String
Unique identifier for this stream
final
muted bool
Whether to mute this stream locally
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
stream MediaStream
The audio stream
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited