widgets/quick_rtc_builder library

Classes

QuickRTCBuilder
A widget that rebuilds when the QuickRTCState changes.

Typedefs

QuickRTCBuildWhen = bool Function(QuickRTCState previous, QuickRTCState current)
Signature for the buildWhen function which takes the previous and current QuickRTCState and returns a boolean indicating whether the builder should be called.
QuickRTCErrorBuilder = Widget Function(BuildContext context, String error)
Signature for the onError builder which takes the BuildContext and error message and returns a widget.
QuickRTCWidgetBuilder = Widget Function(BuildContext context, QuickRTCState state)
Signature for the builder function which takes the BuildContext and QuickRTCState and returns a widget.