QuickRTCBuildWhen typedef

QuickRTCBuildWhen = bool Function(QuickRTCState previous, QuickRTCState current)

Signature for the buildWhen function which takes the previous and current QuickRTCState and returns a boolean indicating whether the builder should be called.

Implementation

typedef QuickRTCBuildWhen = bool Function(
  QuickRTCState previous,
  QuickRTCState current,
);