QuickRTCBuilder class

A widget that rebuilds when the QuickRTCState changes.

QuickRTCBuilder handles building a widget in response to new states. It receives STATE only in the builder callback.

Please refer to QuickRTCListener if you want to "do" anything in response to state changes (navigation, showing dialogs, etc.).

Example:

QuickRTCBuilder(
  buildWhen: (previous, current) => previous.participants != current.participants,
  builder: (context, state) {
    return ParticipantGrid(
      participants: state.participantList,
    );
  },
  onError: (context, error) {
    return ErrorView(message: error);
  },
)
Inheritance

Constructors

QuickRTCBuilder({Key? key, QuickRTCBuildWhen? buildWhen, required QuickRTCWidgetBuilder builder, QuickRTCErrorBuilder? onError})
Creates a QuickRTCBuilder.
const

Properties

builder QuickRTCWidgetBuilder
The builder function that returns the widget tree.
final
buildWhen QuickRTCBuildWhen?
An optional function that determines when the widget should rebuild.
final
hashCode int
The hash code for this object.
no setterinherited
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
onError QuickRTCErrorBuilder?
Optional error builder.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

createElement() StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() State<QuickRTCBuilder>
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited