onError property

QuickRTCErrorBuilder? onError
final

Optional error builder.

If provided and the state has an error, this builder will be called instead of the main builder.

Implementation

final QuickRTCErrorBuilder? onError;