autoRenderAudio property
Whether to automatically include QuickRTCAudioRenderers.
If true (default), remote audio will be rendered automatically. Set to false if you want to handle audio rendering yourself.
Implementation
final bool autoRenderAudio;
Whether to automatically include QuickRTCAudioRenderers.
If true (default), remote audio will be rendered automatically. Set to false if you want to handle audio rendering yourself.
final bool autoRenderAudio;