onJoined property
Called when successfully joined the conference.
Useful for enabling media or other setup after joining.
Implementation
final void Function(QuickRTCController controller)? onJoined;
Called when successfully joined the conference.
Useful for enabling media or other setup after joining.
final void Function(QuickRTCController controller)? onJoined;