QuickRTCProvider class

Provides a QuickRTCController instance to the widget tree.

This widget uses InheritedWidget to efficiently propagate the controller and its state changes to descendant widgets.

Example:

QuickRTCProvider(
  controller: QuickRTCController(socket: socket),
  child: MyApp(),
)

Access the controller:

// For actions (doesn't listen to changes)
final controller = QuickRTCProvider.read(context);
await controller.joinMeeting(...);

// For state (use inside Builder/Listener/Consumer instead)
final state = QuickRTCProvider.stateOf(context);
Inheritance

Constructors

QuickRTCProvider({Key? key, required QuickRTCController controller, required Widget child})
Creates a QuickRTCProvider.
const

Properties

child Widget
The widget below this widget in the tree.
finalinherited
controller QuickRTCController
The QuickRTCController instance to provide.
final
hashCode int
The hash code for this object.
no setterinherited
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

createElement() InheritedElement
Inflates this configuration to a concrete instance.
inherited
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited
updateShouldNotify(covariant QuickRTCProvider oldWidget) bool
Whether the framework should notify widgets that inherit from this widget.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

maybeOf(BuildContext context) QuickRTCController?
Checks if a QuickRTCProvider exists in the widget tree.
of(BuildContext context) QuickRTCController
Gets the QuickRTCController instance and listens for changes.
read(BuildContext context) QuickRTCController
Gets the QuickRTCController instance without listening for changes.
stateOf(BuildContext context) QuickRTCState
Gets the current QuickRTCState and listens for changes.