CustomPosition class

Custom position for fine-grained control

Use this when OverlayPosition presets don't meet your needs.

Constructors

CustomPosition({double? top, double? bottom, double? left, double? right})
const
CustomPosition.bottomLeft({double bottomOffset = 0, double leftOffset = 0})
Create a position anchored to the bottom-left with offsets
const
CustomPosition.bottomRight({double bottomOffset = 0, double rightOffset = 0})
Create a position anchored to the bottom-right with offsets
const
CustomPosition.topLeft({double topOffset = 0, double leftOffset = 0})
Create a position anchored to the top-left with offsets
const
CustomPosition.topRight({double topOffset = 0, double rightOffset = 0})
Create a position anchored to the top-right with offsets
const

Properties

bottom double?
final
hashCode int
The hash code for this object.
no setterinherited
left double?
final
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
top double?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited