ParticipantInfo class abstract
Basic information about a participant
- Annotations
-
- @freezed
Constructors
-
ParticipantInfo({required String participantId, required String participantName, @Default.new([]) List<
String> producerIds}) -
constfactory
-
ParticipantInfo.fromJson(Map<
String, dynamic> json) -
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited