SocketResponse<T> class
abstract
Standard response from socket server
- Annotations
-
- @Freezed.new(genericArgumentFactories: true)
Constructors
- SocketResponse({required String status, T? data, String? error})
-
constfactory
-
SocketResponse.fromJson(Map<
String, dynamic> json, T fromJsonT(Object?)) -
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited