TransportOptions class abstract

Options for creating a WebRTC transport

Annotations
  • @freezed

Constructors

TransportOptions({required String id, required Map<String, dynamic> iceParameters, required List<Map<String, dynamic>> iceCandidates, required Map<String, dynamic> dtlsParameters, Map<String, dynamic>? sctpParameters})
const
factory
TransportOptions.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited