QuickRTCPlatform class

Platform-specific screen capture service handler.

On Android, this starts/stops a foreground service required for MediaProjection API (screen capture) on Android 10+.

On iOS/macOS, this handles screen capture permissions differently:

  • macOS: Uses CGRequestScreenCaptureAccess for permission
  • iOS: Uses ReplayKit

Constructors

QuickRTCPlatform()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

isScreenCaptureServiceRunning bool
Check if the screen capture service is running
no setter

Static Methods

checkScreenCapturePermission() Future<bool>
Check if screen capture permission is granted (macOS only).
checkScreenCaptureServiceRunning() Future<bool>
Check if the screen capture service is currently running.
getAndroidSdkVersion() Future<int>
Get Android SDK version
getPlatformVersion() Future<String?>
Get the platform version string
openScreenCaptureSettings() Future<void>
Open System Preferences to Screen Recording settings (macOS only).
prepareScreenCapture() Future<bool>
Prepare for screen capture on Android 14+ (SDK 34+).
requestScreenCapturePermission() Future<bool>
Request screen capture permission (macOS only).
startScreenCaptureService() Future<bool>
Start the screen capture foreground service.
stopScreenCaptureService() Future<bool>
Stop the screen capture foreground service.