types library

Classes

AudioConfig
Audio configuration
ConnectedEvent
Connected event data
ConsumerInfo
Internal consumer info
ConsumerParamsData
Consumer parameters from server
DisconnectedEvent
Disconnected event data
ErrorEvent
Error event data
JoinConfig
Configuration for joining a conference
LocalMedia
Result from getLocalMedia containing streams and tracks
LocalStream
Local stream handle returned from produce()
LocalStreamEndedEvent
Local stream ended event (e.g., user clicked browser's "Stop sharing" button)
MediaConfig
Configuration for getLocalMedia
NewParticipantEvent
New participant event data Streams array may be empty if participant hasn't started sharing media yet
NewProducerData
Participant
Participant information
ParticipantInfoData
Participant info from server
ParticipantJoinedData
ParticipantLeftData
ParticipantLeftEvent
Participant left event data
ProduceInput
Input for produce() - can be single track, array of tracks, or tracks with types Use the factory methods for convenience
ProducerClosedData
ProducerInfo
Internal producer info
QuickRTCConfig
Configuration for QuickRTC client instance
RemoteParticipant
Remote participant with their streams
RemoteStream
Remote stream from a participant
ScreenShareConfig
Screen share configuration
StreamPausedEvent
Stream paused event (remote participant muted audio/video)
StreamRemovedEvent
Stream removed event data
StreamResumedEvent
Stream resumed event (remote participant unmuted audio/video)
TrackWithType
Track with optional type hint for producing
TransportOptionsData
Transport options from server
VideoConfig
Video configuration

Enums

MediaType
Media types for getLocalMedia
StreamType
Stream types

Extensions

MediaTypeExtension on MediaType
Extension for MediaType
StreamTypeExtension on StreamType
Extension to convert StreamType to/from string

Typedefs

StreamAddedEvent = RemoteStream
Stream added event (for existing participants who start new media)