ConsumerInfo class

Internal consumer info

Constructors

ConsumerInfo({required String id, required StreamType type, required Consumer consumer, required MediaStream stream, required String producerId, required String participantId, required String participantName})
const

Properties

consumer → Consumer
final
hashCode int
The hash code for this object.
no setterinherited
id String
final
participantId String
final
participantName String
final
producerId String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
stream MediaStream
final
type StreamType
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited