JoinConfig class
Configuration for joining a conference
Constructors
Properties
- conferenceId → String
-
Conference/room ID
final
- conferenceName → String?
-
Conference name (optional)
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- participantId → String?
-
Participant ID (auto-generated if not provided)
final
-
participantInfo
→ Map<
String, dynamic> ? -
Extra participant info (permissions, metadata, etc.)
final
- participantName → String
-
Participant display name
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited