NewParticipantEvent class
New participant event data Streams array may be empty if participant hasn't started sharing media yet
Constructors
-
NewParticipantEvent({required String participantId, required String participantName, Map<
String, dynamic> participantInfo = const {}, List<RemoteStream> streams = const []}) -
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- participantId → String
-
Participant ID
final
-
participantInfo
→ Map<
String, dynamic> -
Extra participant info
final
- participantName → String
-
Participant display name
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
streams
→ List<
RemoteStream> -
Streams from this participant (may be empty)
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited