NewProducerData class
Constructors
- NewProducerData({required String producerId, required String participantId, required String participantName, required String kind, StreamType? streamType})
-
const
-
NewProducerData.fromJson(Map<
String, dynamic> json) -
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- kind → String
-
final
- participantId → String
-
final
- participantName → String
-
final
- producerId → String
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- streamType → StreamType?
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited