Participant class
Participant information
Constructors
-
Participant({required String id, required String name, Map<
String, dynamic> info = const {}}) -
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- id → String
-
Participant ID
final
-
info
→ Map<
String, dynamic> -
Extra participant info
final
- name → String
-
Display name
final
-
props
→ List<
Object?> -
The list of properties that will be used to determine whether
two instances are equal.
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- stringify → bool?
-
If set to
true, thetoStringmethod will be overridden to output this instance'sprops.no setterinherited
Methods
-
copyWith(
{String? id, String? name, Map< String, dynamic> ? info}) → Participant - Create a copy with the given fields replaced
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited