ParticipantJoinedData class

Constructors

ParticipantJoinedData({required String participantId, required String participantName, Map<String, dynamic>? participantInfo, required String conferenceId})
const
ParticipantJoinedData.fromJson(Map<String, dynamic> json)
factory

Properties

conferenceId String
final
hashCode int
The hash code for this object.
no setterinherited
participantId String
final
participantInfo Map<String, dynamic>?
final
participantName String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited