RemoteParticipant class
Remote participant with their streams
This class represents a remote participant in the conference, including their identity and all their media streams.
Constructors
-
RemoteParticipant({required String id, required String name, Map<
String, dynamic> info = const {}, List<RemoteStream> streams = const []}) -
const
-
RemoteParticipant.fromParticipant(Participant participant, {List<
RemoteStream> streams = const []}) -
Create from a Participant
factory
Properties
- audioStream → RemoteStream?
-
Get audio stream (null if not available)
no setter
- hasAudio → bool
-
Whether participant has audio
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
-
Whether participant is sharing screen
no setter
- hasVideo → bool
-
Whether participant has video
no setter
- id → String
-
Participant ID
final
-
info
→ Map<
String, dynamic> -
Extra participant info (permissions, metadata, etc.)
final
- isAudioMuted → bool
-
Whether audio stream is muted (paused by remote participant)
no setter
-
Whether screenshare stream is paused
no setter
- isVideoMuted → bool
-
Whether video stream is muted (paused by remote participant)
no setter
- name → String
-
Display name
final
-
props
→ List<
Object?> -
The list of properties that will be used to determine whether
two instances are equal.
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
Get screenshare stream (null if not available)
no setter
-
streams
→ List<
RemoteStream> -
List of streams from this participant
final
- stringify → bool?
-
If set to
true, thetoStringmethod will be overridden to output this instance'sprops.no setterinherited - videoStream → RemoteStream?
-
Get video stream (null if not available)
no setter
Methods
-
addStream(
RemoteStream stream) → RemoteParticipant - Add a stream to this participant
-
copyWith(
{String? id, String? name, Map< String, dynamic> ? info, List<RemoteStream> ? streams}) → RemoteParticipant - Create a copy with the given fields replaced
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
removeStream(
String streamId) → RemoteParticipant - Remove a stream from this participant by ID
-
toString(
) → String - A string representation of this object.
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited