RemoteStream class
Remote stream from a participant
Constructors
- RemoteStream({required String id, required StreamType type, required MediaStream stream, required String producerId, required String participantId, required String participantName, bool paused = false})
-
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- id → String
-
Unique stream ID (consumer ID)
final
- participantId → String
-
Participant ID who owns this stream
final
- participantName → String
-
Participant name
final
- paused → bool
-
Whether the stream is paused (muted by remote participant)
final
- producerId → String
-
Producer ID on the server
final
-
props
→ List<
Object?> -
The list of properties that will be used to determine whether
two instances are equal.
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- stream → MediaStream
-
The MediaStream
final
- stringify → bool?
-
If set to
true, thetoStringmethod will be overridden to output this instance'sprops.no setterinherited - type → StreamType
-
Stream type
final
Methods
-
copyWith(
{String? id, StreamType? type, MediaStream? stream, String? producerId, String? participantId, String? participantName, bool? paused}) → RemoteStream - Create a copy with the given fields replaced
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited