ScreenShareConfig class
Screen share configuration
Constructors
-
const
Properties
- frameRate → int?
-
Preferred frame rate
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- height → int?
-
Preferred height
final
- includeSystemAudio → bool
-
Include system audio (supported on some platforms)
final
- preferWindow → bool
-
For desktop: prefer window capture over full screen
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- width → int?
-
Preferred width
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toConstraints(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- defaultConfig → const ScreenShareConfig
- Default screen share config (1080p, 30fps)
- highQuality → const ScreenShareConfig
- High quality screen share (1080p, 60fps)