TrackWithType class
Track with optional type hint for producing
Constructors
- TrackWithType({required MediaStreamTrack track, StreamType? type, MediaStream? sourceStream})
-
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sourceStream → MediaStream?
-
The original MediaStream from getUserMedia.
On macOS, the camera is only released when this specific stream is disposed.
Pass this to ensure proper camera release on pause.
final
- track → MediaStreamTrack
-
final
- type → StreamType?
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited