sourceStream property
The original MediaStream from getUserMedia. On macOS, the camera is only released when this specific stream is disposed. Pass this to ensure proper camera release on pause.
Implementation
final MediaStream? sourceStream;
The original MediaStream from getUserMedia. On macOS, the camera is only released when this specific stream is disposed. Pass this to ensure proper camera release on pause.
final MediaStream? sourceStream;