buildWhen property
An optional function that determines when the widget should rebuild.
If null, the widget will rebuild on every state change.
Return true to rebuild, false to skip the rebuild.
Implementation
final QuickRTCBuildWhen? buildWhen;
An optional function that determines when the widget should rebuild.
If null, the widget will rebuild on every state change.
Return true to rebuild, false to skip the rebuild.
final QuickRTCBuildWhen? buildWhen;