onError property
Optional error builder.
If provided and the state has an error, this builder will be called instead of the main builder.
Implementation
final QuickRTCErrorBuilder? onError;
Optional error builder.
If provided and the state has an error, this builder will be called instead of the main builder.
final QuickRTCErrorBuilder? onError;