errorBuilder property
Optional builder for error states.
If not provided, shows a simple error message with retry button.
The retry callback can be called to attempt reconnection.
Implementation
final QuickRTCConferenceErrorBuilder? errorBuilder;
Optional builder for error states.
If not provided, shows a simple error message with retry button.
The retry callback can be called to attempt reconnection.
final QuickRTCConferenceErrorBuilder? errorBuilder;