QuickRTCConsumerLite class
A simpler consumer that doesn't include a Provider.
Use this when you already have a QuickRTCProvider ancestor in the tree and just need listener + builder functionality.
For most cases, prefer using QuickRTCConsumer which includes the provider.
Example:
// Already inside a QuickRTCProvider...
QuickRTCConsumerLite(
listenWhen: (prev, curr) => prev.error != curr.error,
listener: (context, controller) {
// Handle errors
},
builder: (context, state) {
return MyWidget(participants: state.participantList);
},
)
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- StatelessWidget
- QuickRTCConsumerLite
Constructors
- QuickRTCConsumerLite({Key? key, QuickRTCBuildWhen? buildWhen, required QuickRTCWidgetBuilder builder, QuickRTCListenWhen? listenWhen, required QuickRTCWidgetListener listener, QuickRTCErrorBuilder? onError})
-
Creates a QuickRTCConsumerLite.
const
Properties
- builder → QuickRTCWidgetBuilder
-
Builder that receives (context, state)
final
- buildWhen → QuickRTCBuildWhen?
-
Optional condition for when to rebuild
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
- listener → QuickRTCWidgetListener
-
Listener that receives (context, controller)
final
- listenWhen → QuickRTCBuildWhen?
-
Optional condition for when to call listener
final
- onError → QuickRTCErrorBuilder?
-
Optional error builder
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
build(
BuildContext context) → Widget -
Describes the part of the user interface represented by this widget.
override
-
createElement(
) → StatelessElement -
Creates a StatelessElement to manage this widget's location in the tree.
inherited
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited