QuickRTCMediaRendererState class
State data exposed by the renderer
Can be used to build custom overlays based on renderer state.
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- hasStream → bool
-
Whether a stream is attached
final
- hasVideoTracks → bool
-
Whether video tracks are present in the stream
final
- isAudioEnabled → bool
-
Whether audio is enabled (from track or explicit override)
final
- isLoading → bool
-
Whether the renderer is still initializing
final
- isVideoEnabled → bool
-
Whether video is enabled (from track or explicit override)
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- shouldShowVideo → bool
-
Whether video should be displayed (enabled and has tracks)
no setter
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited